package mapeadores;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

import modelo.Aluno;
import modelo.Curso;

public class MapeadorAluno {

	private Connection con;
	private MapeadorCurso mapeadorCurso;
	
	public MapeadorAluno(Connection con){
		this.con = con;
		this.mapeadorCurso = new MapeadorCurso(con);
	}

	public void put(Aluno aluno) throws SQLException {
		if (this.get(aluno.retornaMatricula())!=null) {
			atualizaAlunoExistente(aluno);	
		} 
		else {
			insereNovoAluno(aluno);	
		}	
	}

	private void insereNovoAluno(Aluno aluno) throws SQLException {
		PreparedStatement stmt = con.prepareStatement("INSERT INTO ALUNO (MATRICULA,NOME,ENDERECO,CURSO) "+
			"VALUES (?,?,?,?)");
		try{	
			stmt.setInt(1,aluno.retornaMatricula());	
			stmt.setString(2,aluno.retornaNome());	
			stmt.setString(3,aluno.retornaEndereco());	
			if (aluno.retornaCurso() == null)
				stmt.setNull(4, Types.INTEGER);
			else 	
				stmt.setInt(4,aluno.retornaCurso().retornaCodigo());
			stmt.execute();
		}
		finally {	
			stmt.close();
		}
	}

	private void atualizaAlunoExistente(Aluno aluno) throws SQLException {
		PreparedStatement stmt = con.prepareStatement("UPDATE ALUNO SET NOME=?,ENDERECO=?,"+
			"CURSO=? WHERE MATRICULA=?");			
		try{	
			
			stmt.setString(1,aluno.retornaNome());	
			stmt.setString(2,aluno.retornaEndereco());	
			if (aluno.retornaCurso() == null)
				stmt.setNull(3, Types.INTEGER);
			else 	
				stmt.setInt(3,aluno.retornaCurso().retornaCodigo());
			stmt.setInt(4,aluno.retornaMatricula());	
			stmt.execute();
		}
		finally{
			stmt.close();
		}
	}

	public Aluno get(int matricula) throws SQLException{
		Aluno aluno;
		PreparedStatement stmt = con.prepareStatement("SELECT NOME,ENDERECO,CURSO " +
				"FROM ALUNO WHERE MATRICULA=?");
		stmt.setInt(1,matricula);	
		ResultSet rs = stmt.executeQuery();
		try{
			if (rs.next()){
				String nome = rs.getString("NOME");
				String endereco = rs.getString("ENDERECO");
				this.mapeadorCurso = new MapeadorCurso(con);
				Curso curso = mapeadorCurso.get(rs.getInt("CURSO"));
				aluno = new Aluno (matricula,nome);
				aluno.atribuiEndereco(endereco);
				aluno.atribuiCurso(curso);
				return aluno;
			}
			else
				return null;
		}
		finally {
			rs.close();
			stmt.close();		
		}
	}

	public void remove(int matricula) throws SQLException{
		PreparedStatement stmt = con.prepareStatement("DELETE FROM ALUNO WHERE MATRICULA=?");
		stmt.setInt(1,matricula);	
		stmt.execute();
		stmt.close();		
	}
	
	
}
