package modelo;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;

import mapeadores.MapeadorAluno;
import mapeadores.MapeadorCurso;

public class Universidade {
	
	private Connection con;
	private MapeadorAluno mapeadorAluno;
	private MapeadorCurso mapeadorCurso;
	
	public Universidade (){
    	try {
    		// BD Postgres
	    	Class.forName("org.postgresql.Driver");
	    	this.con = DriverManager.getConnection("jdbc:postgresql://localhost/mapeamento-postgres","postgres", "postgres");
	    	this.mapeadorAluno = new MapeadorAluno(this.con);
	    	this.mapeadorCurso = new MapeadorCurso(this.con);
    	} catch (Exception e) {
    		e.printStackTrace();
    		throw new java.lang.RuntimeException("erro ao conectar");
    	}
	}
	
	public void apagaTodosDadosDoBD () {
		Statement stmt = null;
		try{	
			stmt = con.createStatement();
			stmt.executeUpdate("DELETE FROM ALUNO");
			stmt.executeUpdate("DELETE FROM CURSO");
    	} 
		catch (SQLException e) {
    		e.printStackTrace();
    		throw new java.lang.RuntimeException("erro ao apagar todos os dados do BD");
		}
		finally{
			try { stmt.close(); } 
			catch (Exception ignore) {};
		}	
	} 		

	public void cadastraAluno(int matricula, String nome, String endereco, int codigoCurso) {
		try {
			Curso curso = mapeadorCurso.get(codigoCurso); 
			Aluno aluno = new Aluno(matricula, nome);
			aluno.atribuiEndereco(endereco);
			aluno.atribuiCurso(curso);
			mapeadorAluno.put (aluno);
		} catch (SQLException e) {
			e.printStackTrace();
		}		
	}

	public void cadastraAluno(int matricula, String nome, String endereco) {
		try {
			Aluno aluno = new Aluno(matricula, nome);
			aluno.atribuiEndereco(endereco);
			mapeadorAluno.put (aluno);
		} catch (SQLException e) {
			e.printStackTrace();
		}		
	}

	public Aluno retornaAluno(int matricula) {
		try {
			return mapeadorAluno.get(matricula);
		} catch (SQLException e) {
			e.printStackTrace();
		}
		return null;
	}

	public void cadastraCurso(int codigo, String nome, String centro) {
		Curso curso = new Curso(codigo);
		curso.atribuiNome(nome);
		curso.atribuiCentro(centro);
		try {
			mapeadorCurso.put(curso);
		} catch (SQLException e) {
			e.printStackTrace();
		}	
	}

	public Curso retornaCurso(int codigo) {
		try {
			return mapeadorCurso.get(codigo);
		} catch (SQLException e) {
			e.printStackTrace();
		}
		return null;
	}

	public void removeCurso(int codigo) {
		try {
			mapeadorCurso.remove(codigo);
		} catch (SQLException e) {
			e.printStackTrace();
		}
		
	}

	public void removeAluno(int matricula) {
		try {
			mapeadorAluno.remove(matricula);
		} catch (SQLException e) {
			e.printStackTrace();
		}
	}	


}
